@@ -4,6 +4,7 @@ use strict;
 use warnings;
 use Moo;
 use warnings NONFATAL => 'all';
+use AE;
 use AnyEvent;
 use AnyEvent::Handle;
 use AnyEvent::Socket qw( tcp_connect );
@@ -12,7 +13,7 @@ use AnyEvent::WebSocket::Connection;
 use PerlX::Maybe qw( maybe provided );
 
 # ABSTRACT: WebSocket client for AnyEvent
-our $VERSION = '0.22'; # VERSION
+our $VERSION = '0.23'; # VERSION
 
 
 has timeout => (
@@ -40,7 +41,7 @@ sub connect
     $uri = URI->new($uri);
   }
   
-  my $done = AnyEvent->condvar;
+  my $done = AE::cv;
 
   # TODO: should we also accept http and https URLs?
   # probably.
@@ -115,7 +116,7 @@ AnyEvent::WebSocket::Client - WebSocket client for AnyEvent
 
 =head1 VERSION
 
-version 0.22
+version 0.23
 
 =head1 SYNOPSIS
 
@@ -127,6 +128,8 @@ version 0.22
    my $connection = eval { shift->recv };
    if($@) {
      # handle error...
+     warn $@;
+     return;
    }
    
    # send a message through the websocket...
@@ -203,6 +206,19 @@ This is pretty simple minded and there are probably WebSocket features
 that you might like to use that aren't supported by this distribution.
 Patches are encouraged to improve it.
 
+If you see warnings like this:
+
+ Class::MOP::load_class is deprecated at /home/ollisg/.perlbrew/libs/perl-5.18.2c34@dev/lib/perl5/x86_64-linux/Class/MOP.pm line 71.
+ Class::MOP::load_class("Crypt::Random::Source::Weak::devurandom") called at /home/ollisg/.perlbrew/libs/perl-5.18.2c34@dev/lib/perl5/Crypt/Random/Source/Factory.pm line 137
+ ...
+
+The problem is in the optional L<Crypt::Random::Source> module, and has
+been reported here:
+
+https://rt.cpan.org/Ticket/Display.html?id=93163&results=822cf3902026ad4a64ae94b0175207d6
+
+You can use the patch provided there to silence the warnings.
+
 =head1 SEE ALSO
 
 =over 4
